@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.032';
+our $VERSION = '1.038';
 
 use Log::Any::Manager;
 use Log::Any::Adapter::Util qw(
@@ -120,7 +120,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.032
+version 1.038
 
 =head1 SYNOPSIS
 
@@ -138,11 +138,11 @@ In a CPAN or other module:
 In a Moo/Moose-based module:
 
     package Foo;
+    use Log::Any ();
     use Moo;
 
     has log => (
         is => 'ro',
-        isa => 'Log::Any::Proxy',
         default => sub { Log::Any->get_logger },
     );
 
@@ -198,6 +198,14 @@ whether the application has chosen (or will ever choose) a logging mechanism.
 See L<http://www.openswartz.com/2007/09/06/standard-logging-api/> for the
 original post proposing this module.
 
+=head1 NAME
+
+Log::Any - Bringing loggers and listeners together
+
+=head1 VERSION
+
+version 1.038
+
 =head1 LOG LEVELS
 
 C<Log::Any> supports the following log levels and aliases, which is meant to be
@@ -246,6 +254,18 @@ If no category is specified, the calling package is used.
 A logger object is an instance of L<Log::Any::Proxy>, which passes
 on messages to the L<Log::Any::Adapter> handling its category.
 
+If the C<proxy_class> argument is passed, an alternative to
+L<Log::Any::Proxy> (such as a subclass) will be instantiated and returned
+instead.  The argument is automatically prepended with "Log::Any::Proxy::".
+If instead you want to pass the full name of a proxy class, prefix it with
+a "+". E.g.
+
+    # Log::Any::Proxy::Foo
+    my $log = Log::Any->get_logger(proxy_class => 'Foo');
+
+    # MyLog::Proxy
+    my $log = Log::Any->get_logger(proxy_class => '+MyLog::Proxy');
+
 =head2 Logging
 
 To log a message, pass a single string to any of the log levels or aliases. e.g.
@@ -405,12 +425,84 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Maxim Vuets Stephen Thirlwall
+=for stopwords cm-perl David Golden Maxim Vuets Stephen Thirlwall
 
 =over 4
 
 =item *
 
+cm-perl <cm-perl@users.noreply.github.com>
+
+=item *
+
+David Golden <xdg@xdg.me>
+
+=item *
+
+Maxim Vuets <maxim.vuets@booking.com>
+
+=item *
+
+Stephen Thirlwall <sdt@dr.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/dagolden/Log-Any/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/dagolden/Log-Any>
+
+  git clone https://github.com/dagolden/Log-Any.git
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords cm-perl David Golden Maxim Vuets Stephen Thirlwall
+
+=over 4
+
+=item *
+
+cm-perl <cm-perl@users.noreply.github.com>
+
+=item *
+
+David Golden <xdg@xdg.me>
+
+=item *
+
 Maxim Vuets <maxim.vuets@booking.com>
 
 =item *
