@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter;
 
 # ABSTRACT: Tell Log::Any where to send its logs
-our $VERSION = '1.032';
+our $VERSION = '1.038';
 
 use Log::Any;
 
@@ -38,7 +38,7 @@ Log::Any::Adapter - Tell Log::Any where to send its logs
 
 =head1 VERSION
 
-version 1.032
+version 1.038
 
 =head1 SYNOPSIS
 
@@ -78,6 +78,14 @@ Log::Any::Adapter connects log producers and log consumers.  Its methods
 instantiate a logging adapter (a subclass of L<Log::Any::Adapter::Base>)
 and route log messages from one or more categories to it.
 
+=head1 NAME
+
+Log::Any::Adapter - Tell Log::Any where to send its logs
+
+=head1 VERSION
+
+version 1.038
+
 =head1 ADAPTERS
 
 In order to use a logging mechanism with C<Log::Any>, there needs to be an
@@ -177,7 +185,10 @@ adapter setting will be removed. e.g.
 
 =back
 
-C<set> returns an entry object, which can be passed to C<remove>.
+C<set> returns an entry object, which can be passed to C<remove>.  If you
+call C<set> repeatedly without calling C<remove> you will leak memory.  For
+most programs that set an adapter once until the end of the program, this
+shouldn't matter.
 
 =item use Log::Any::Adapter (...)
 
@@ -190,11 +201,25 @@ Remove an I<entry> previously returned by C<set>.
 
 =back
 
-=head1 MULTIPLE ADAPTER SETTINGS
+=head1 USING MORE THAN ONE ADAPTER
 
-C<Log::Any> maintains a stack of entries created via C<set>.
+C<Log::Any> maintains a stack of entries created via C<set>.  If you call
+C<set> repeatedly, you will leak memory unless you do one of the
+following:
 
-When you get a logger for a particular category, C<Log::Any> will work its way
+=over 4
+
+=item *
+
+call C<remove> on the adapter returned from C<set> when you are done with it
+
+=item *
+
+use the C<lexically> feature to set a guard variable that will clean it up when it goes out of scope
+
+=back
+
+When getting a logger for a particular category, C<Log::Any> will work its way
 down the stack and use the first matching entry.
 
 Whenever the stack changes, any C<Log::Any> loggers that have previously been
@@ -235,4 +260,25 @@ This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
