@@ -5,10 +5,10 @@ use warnings;
 package Log::Any::Adapter::Util;
 
 # ABSTRACT: Common utility functions for Log::Any
-our $VERSION = '1.032';
+our $VERSION = '1.038';
 
-use Data::Dumper;
-use base qw(Exporter);
+use Exporter;
+our @ISA = qw/Exporter/;
 
 my %LOG_LEVELS;
 BEGIN {
@@ -135,12 +135,23 @@ sub numeric_level {
 #pod
 #pod =cut
 
-sub dump_one_line {
-    my ($value) = @_;
+# lazy trampoline to load Data::Dumper only on demand but then not try to
+# require it pointlessly each time
+*dump_one_line = sub {
+    require Data::Dumper;
 
-    return Data::Dumper->new( [$value] )->Indent(0)->Sortkeys(1)->Quotekeys(0)
-      ->Terse(1)->Dump();
-}
+    my $dumper = sub {
+        my ($value) = @_;
+
+        return Data::Dumper->new( [$value] )->Indent(0)->Sortkeys(1)->Quotekeys(0)
+        ->Terse(1)->Useqq(1)->Dump();
+    };
+
+    my $string = $dumper->(@_);
+    no warnings 'redefine';
+    *dump_one_line = $dumper;
+    return $string;
+};
 
 #pod =func make_method
 #pod
@@ -187,7 +198,7 @@ sub read_file {
     my ($file) = @_;
 
     local $/ = undef;
-    open( my $fh, '<', $file )
+    open( my $fh, '<:utf8', $file ) ## no critic
       or die "cannot open '$file': $!";
     my $contents = <$fh>;
     return $contents;
@@ -230,7 +241,7 @@ Log::Any::Adapter::Util - Common utility functions for Log::Any
 
 =head1 VERSION
 
-version 1.032
+version 1.038
 
 =head1 DESCRIPTION
 
@@ -257,6 +268,14 @@ constants will be imported:
     DEBUG     => 7
     TRACE     => 8
 
+=head1 NAME
+
+Log::Any::Adapter::Util - Common utility functions for Log::Any
+
+=head1 VERSION
+
+version 1.038
+
 =head1 FUNCTIONS
 
 =head2 logging_methods
@@ -337,4 +356,25 @@ This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
